# example of a structured LP formulation
# model syntax is declarative
# structured formulations define classes of problems
# instances are given by the mapping parameters -> values in the .dat file

# sets
param n integer, >=1;       # number of columns
param m integer, >=1, <= n; # number of rows
set I := 1..m;              # set of row indices (to quantify over)
set J := 1..n;              # set of column indices (to quantify over)

# parameters
param c{J} default 0;   # objective function vector
param b{I} default 0;   # rhs vector
param A{I,J} default 0; # constraint matrix

# decision variables
var x{J} >= 0;       # nonnegative decision variables

# objective function
minimize objfun: sum{j in J} c[j]*x[j];  # every entity is named

# constraints
# equation constraints for an LP in standard form
subject to constraints{i in I}: sum{j in J} A[i,j]*x[j] = b[i];

# quantification is achieved with the set notation, e.g. {j in J}
